@@ -1,10 +1,11 @@
 """Module of logging models."""
 
 import datetime
-from typing import Any, Optional
+import json
+from typing import Any, Optional, Union
 
 import sqlalchemy as sa
-from sqlalchemy import JSON
+from pydantic import field_validator
 from sqlmodel import Field, SQLModel
 
 
@@ -28,11 +29,6 @@ class LogModel(SQLModel):
     timestamp: datetime.datetime = Field(
         title='Date and time of the request',
     )
-    session: Optional[dict[str, Any]] = Field(
-        title='User session data',
-        default_factory=dict,
-        sa_type=JSON,
-    )
     method: Optional[str] = Field(
         default=None,
         title='HTTP method',
@@ -47,7 +43,24 @@ class LogModel(SQLModel):
         default=None,
         title='Status',
     )
-    message: str = Field(
-        title='All data',
+    logger: Optional[str] = Field(
+        default=None,
+        title='Logger name',
         sa_type=sa.Text,
     )
+    level: Optional[str] = Field(
+        default=None,
+        title='Level',
+        sa_type=sa.Text,
+    )
+    message: dict[str, Any] = Field(
+        title='All data',
+        sa_type=sa.JSON,
+    )
+
+    @field_validator('message', mode='before')
+    @classmethod
+    def _convert(cls, value: Union[str, dict[str, Any]]) -> Any:  # noqa: ANN401
+        if isinstance(value, str):
+            return json.loads(value)
+        return value
