@@ -2,12 +2,11 @@
 
 Provides Sentry configuration functions for quick integration to the application.
 """
-from .initialization import init_sentry, setup_sentry
+from .initialization import setup_sentry
 from .settings import Environment, SentrySettings
 
 __all__ = (
     'setup_sentry',
-    'init_sentry',
     'SentrySettings',
     'Environment',
 )
